@@ -232,20 +232,28 @@ class ModelFitter(object):
             raise ValueError("Must do fitModel before reportFit.")
         return str(lmfit.fit_report(self.minimizer_result))
 
-    def plotResiduals(self, figSize=None, **kwargs):
+    def plotResiduals(self, figsize=None, **kwargs):
         options = PlotOptions()
         plotter = TimeseriesPlotter(is_plot=self._is_plot)
-        if figSize != None:
-           options.figsize = figSize
+        if figsize != None:
+           options.figsize = figsize
         options.marker1 = "o"
         plotter.plotTimeSingle(self.residual_ts, options=options, **kwargs)
 
-    def plotFit(self, figSize=None, **kwargs):
+    def plotFit(self, figsize=None, **kwargs):
         options = PlotOptions()
         plotter = TimeseriesPlotter(is_plot=self._is_plot)
         options.marker2 = "o"
-        if figSize != None:
-           options.figsize = figSize
+        if figsize != None:
+           options.figsize = figsize
         plotter.plotTimeSingle(self.fitted_ts, timeseries2=self.observed_ts, options=options, **kwargs)
 
- 
\ No newline at end of file
+    def plotFitAll (self, figsize=None):
+        data = fitter.fitted_ts.values
+        expdata = fitter.observed_ts.values
+
+        plt.figure(figsize=figsize)
+        for i in range (len (data[0])-1):
+            plt.plot (data[:,0], data[:,i+1])
+        for i in range (len (expdata[0])-1):
+            plt.scatter (expdata[:,0], expdata[:,i+1], marker='o')
\ No newline at end of file
